<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Devices.I2c.Provider

Windows Runtime (WinRT) APIs for for the `Windows.Devices.I2c.Provider` namespace.

This package provides the `winrt.windows.devices.i2c.provider` module.
